0.9.9 API documentation: GLM_GTX_optimum_pow

| 0.9.9 API documentation

- Main Page
- Modules
- Files

Functions
GLM_GTX_optimum_pow
Experimental extensions

Include <glm/gtx/optimum_pow.hpp> to use the features of this extension. More...

## Functions
template<typename genType >
GLM_FUNC_DECL genType | pow2 (genType const &x)
| Returns x raised to the power of 2. More...
template<typename genType >
GLM_FUNC_DECL genType | pow3 (genType const &x)
| Returns x raised to the power of 3. More...
template<typename genType >
GLM_FUNC_DECL genType | pow4 (genType const &x)
| Returns x raised to the power of 4. More...

## Detailed Description

Include <glm/gtx/optimum_pow.hpp> to use the features of this extension.

Integer exponentiation of power functions.

## Function Documentation

GLM_FUNC_DECL genType glm::gtx::pow2 | ( | genType const & | x | ) |

Returns x raised to the power of 2.

See also
  GLM_GTX_optimum_pow

GLM_FUNC_DECL genType glm::gtx::pow3 | ( | genType const & | x | ) |

Returns x raised to the power of 3.

See also
  GLM_GTX_optimum_pow

GLM_FUNC_DECL genType glm::gtx::pow4 | ( | genType const & | x | ) |

Returns x raised to the power of 4.

See also
  GLM_GTX_optimum_pow